###############
Further Reading
###############

Find examples for the application of FINE in the following published articles: 

* Welder et al. (2019): `Design and evaluation of hydrogen electricity reconversion pathways in national energy systems using spatially and temporally resolved energy system optimization <https://www.sciencedirect.com/science/article/abs/pii/S0360319918338552>`_.


* Caglayan et al. (2019): `Impact of Different Weather Years on the Design of Hydrogen Supply Pathways for Transport Needs <https://www.sciencedirect.com/science/article/abs/pii/S0360319919329489>`_ .


* Caglayan et al. (2019): `The techno-economic potential of offshore wind energy with optimized future turbine designs in Europe <https://www.sciencedirect.com/science/article/abs/pii/S0306261919314813?via%3Dihub>`_ .


* Kannengießer et al. (2020): `Reducing Computational Load for Mixed Integer Linear Programming: An Example for a District and an Island Energy System <https://www.mdpi.com/1996-1073/12/14/2825>`_ .


